<?php

/* Globals */
define( 'ASSEMBLY_THEME_VERSION', '1.0.2' );
define( 'ASSEMBLY_THEME_NAME', 'assembly-bloc' );
define( 'ASSEMBLY_THEME_UPDATE_ID', '4208' );


if( function_exists( 'asm_set_setting' ) ){

  asm_set_setting( 'theme_version', ASSEMBLY_THEME_VERSION );
  asm_set_setting( 'theme_name', ASSEMBLY_THEME_NAME );
  asm_set_setting( 'theme_update_id', ASSEMBLY_THEME_UPDATE_ID );

}


/* CONTENT WIDTH */
if ( ! isset( $content_width ) ) {
  $content_width = 940;
}


/*
*  asm_bloc_include_files
*
*  asm_bloc_include_files
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_include_files() {

    $files = array(

        // TGM-Plugin-Activation
        get_template_directory() . '/includes/class-tgm-plugin-activation.php',

        // Assembly fields
        get_template_directory() . '/includes/assembly_fields.php',

    );

    foreach ( $files as $file ) {

        if ( file_exists( $file ) ) require_once $file;

    }

}

// Include files
asm_bloc_include_files();


/*
*  asm_bloc_setup
*
*  asm_bloc_setup
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_setup() {

    // Theme Support
    add_theme_support( 'title-tag' );
    add_theme_support( 'html5', array(
        'comment-list',
        'comment-form',
        'search-form',
        'gallery',
        'caption'
    ) );
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'post-thumbnails' );


    // Translation Ready
    load_theme_textdomain( 'assembly-bloc', get_template_directory() . '/languages' );


    // Image sizes
    //add_image_size( 'large', 600 );
    //add_image_size( 'extra-large', 1200 );

}

// After theme setup
add_action( 'after_setup_theme', 'asm_bloc_setup' );


/*
*  asm_bloc_enqueue_scripts
*
*  asm_bloc_enqueue_scripts
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_enqueue_scripts() {

    // Private variables
    $d = get_template_directory_uri();
    $scripts = array();
    $styles = array();
    

    // STYLES

    // Base framework
    $styles['asm-theme-framework'] = array(
        'src'       => $d . '/css/framework.css',
        'deps'      => false,
    );
    
    // Include ss-social-font
    $styles['asm-theme-ss-social-font'] = array(
        'src'       => $d . '/fonts/ss-social-regular.css',
        'deps'      => array( 'asm-theme-framework' ),
    );

    // Main Styles
    $styles['asm-theme-main-styles'] = array(
        'src'       => get_stylesheet_uri(),
        'deps'      => array( 'asm-theme-ss-social-font', 'asm-wp-base', 'asm-theme-framework' ),
    );

    // Enqueue both parent and child styles in child theme
    if( is_child_theme() ) {
        $styles['asm-theme-parent-styles'] = array(
            'src'       => $d . '/style.css',
            'deps'      => array( 'asm-theme-ss-social-font', 'asm-wp-base', 'asm-theme-framework', 'asm-theme-main-styles' ),
        );
    }

    // Register styles
    foreach( $styles as $handle => $style ) {

        wp_enqueue_style( $handle, $style['src'], $style['deps'], ASSEMBLY_THEME_VERSION );
        
    }


    // SCRIPTS

    // Enqueue jQuery
    wp_enqueue_script( 'jquery' );

    // Framework
    $scripts['asm-theme-framework'] = array(
        'src'   => $d . '/js/framework.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Appear
    $scripts['asm-theme-appear'] = array(
        'src'   => $d . '/js/jquery.appear.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Isotope
    $scripts['asm-theme-isotope'] = array(
        'src'   => $d . '/js/isotope.pkgd.min.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Packery
    $scripts['asm-theme-packery-mode'] = array(
        'src'   => $d . '/js/packery-mode.pkgd.min.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Global Script
    $scripts['asm-theme-main-scripts'] = array(
        'src'   => $d . '/js/scripts.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Comment reply script
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    // Register scripts
    foreach( $scripts as $handle => $script ) {
        
        wp_enqueue_script( $handle, $script['src'], $script['deps'], ASSEMBLY_THEME_VERSION, $script['footer'] );
        
    }

}

// Enqueue Theme Styles & Scripts
add_action( 'wp_enqueue_scripts', 'asm_bloc_enqueue_scripts' );


/* TGM Plugin Activation */

/*
*  asm_bloc_register_required_plugins
*
*  asm_bloc_register_required_plugins
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_register_required_plugins() {

  $plugins = array(

    array(
      'name'               => 'Assembly Website Builder',
      'slug'               => 'assembly',
      'source'             => 'https://loopthemes.com/tgm/assembly.zip',
      'required'           => true,
      'version'            => '0.5',
      'force_activation'   => true,
      'force_deactivation' => true,
      'plugin_info_hooked' => true,
      //'external_url'       => '',
    ),

    array(
      'name'               => 'Assembly Gallery',
      'slug'               => 'assembly-gallery',
      'source'             => 'https://loopthemes.com/tgm/assembly-gallery.zip',
      'required'           => true,
      'version'            => '0.5',
      'force_activation'   => true,
      'force_deactivation' => true,
      'plugin_info_hooked' => true,
      //'external_url'       => '',
    ),

    // Contact Form 7
    array(
      'name'      => 'Contact Form 7',
      'slug'      => 'contact-form-7',
      'required'  => false,
    ),

  );


  // Configuration
  $config = array(
    'id'           => 'assembly-bloc',
    'default_path' => '',
    'menu'         => 'tgmpa-install-plugins',
    'parent_slug'  => 'themes.php',
    'capability'   => 'edit_theme_options',
    'has_notices'  => true,
    'dismissable'  => false,
    'dismiss_msg'  => '',
    'is_automatic' => true,
    'message'      => ''
  );


  tgmpa( $plugins, $config );

}

add_action( 'tgmpa_register', 'asm_bloc_register_required_plugins' );


/*
*  asm_bloc_tgmpa_message_styles
*
*  asm_bloc_tgmpa_message_styles
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_tgmpa_message_styles() {

  echo "<style>#setting-error-tgmpa{ display: table; }</style>";

}

add_action('admin_head', 'asm_bloc_tgmpa_message_styles');


/*
*  asm_bloc_validate
*
*  asm_bloc_validate
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_validate() {

  if( function_exists( 'asm_set_setting' ) ){

    // Get the page
    $the_id = asm_get_setting( 'page_id' );
    $the_page = get_page( $the_id );


    // If we are previewing notice it
    if( is_preview() ){
        esc_html_e( "The current page has not yet been published, please publish the page or post in order to see the content.", 'assembly-bloc' );
        exit;
    }


    // Validate page
    if( ! isset( $the_page ) ){
        sprintf( esc_html__( "The current page seems to be misconfigured, please <strong><a href=\"%s\">click here</a></strong> to check the \"Page States\" under the \"General\" settings.", 'assembly-bloc' ), admin_url( 'admin.php?page=asm-options?#page_states' ) );
        exit;
    }


    // Return
    return array( 'the_id' => $the_id, 'the_page' => $the_page );

  }else{

    // Return
    require get_template_directory() . '/static/index.php'; exit;

  }

}


/* STATIC */

/*
*  asm_bloc_static_widgets_init
*
*  asm_bloc_static_widgets_init
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_static_widgets_init() {

    if( class_exists('asm') )
      return;

    // Register Sidebar
    register_sidebar( array(
        'name' => __( 'Side Sidebar', 'assembly-bloc' ),
        'id' => 'left-sidebar',
        'description' => esc_html__( 'Widgets in this area will be shown on all posts and pages.', 'assembly-bloc' ),
        'before_widget' => '<div id="%1$s" class="asm-widget widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="asm-widget-title">',
        'after_title'   => '</h4>'
    ) );

}

// Register Widgets
add_action( 'widgets_init', 'asm_bloc_static_widgets_init' );


/*
*  asm_bloc_static_menus_init
*
*  asm_bloc_static_menus_init
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/


function asm_bloc_static_menus_init() {

    if( class_exists('asm') )
      return;

    // Register Menus
    register_nav_menus(
        array(
            "main-menu" => esc_html__( "Main Menu", 'assembly-bloc'  ),
            "footer-menu" => esc_html__( "Footer Menu", 'assembly-bloc'  )
        )
    );

}

// Register menus
add_action( "init", "asm_bloc_static_menus_init" );


/*
*  asm_bloc_static_enqueue_scripts
*
*  asm_bloc_static_enqueue_scripts
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_static_enqueue_scripts() {

    if( class_exists('asm') )
      return;


    // Private variables
    $d = get_template_directory_uri();
    $scripts = array();
    $styles = array();
    

    // STYLES


    // WP base
    $styles['asm-wp-base'] = array(
        'src'       => $d . '/static/css/wp-base.css',
        'deps'      => array( 'asm-theme-ss-social-font', 'asm-theme-framework' ),
    );

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'assembly-bloc' ) ) {
        
        // Google fonts
        $styles['asm-google-fonts-css'] = array(
            'src'       => add_query_arg( 'family', urlencode( 'Suranna:regular|Roboto:300,regular&subset=latin' ), "//fonts.googleapis.com/css" ),
            'deps'      => array( 'asm-theme-ss-social-font', 'asm-wp-base', 'asm-theme-framework' ),
        );
    }

    // WP Generated
    $styles['asm-generated'] = array(
        'src'       => $d . '/static/css/asm-generated.css',
        'deps'      => array( 'asm-theme-ss-social-font', 'asm-wp-base', 'asm-theme-framework', 'asm-theme-main-styles' ),
    );

    // Register styles
    foreach( $styles as $handle => $style ) {

        wp_enqueue_style( $handle, $style['src'], $style['deps'], ASSEMBLY_THEME_VERSION );
        
    }


    // SCRIPTS

    // Framework
    $scripts['asm-theme-app'] = array(
        'src'   => $d . '/static/js/app.js',
        'deps'  => array( 'jquery' ),
        'footer'=> true
    );

    // Comment reply script
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    // Register scripts
    foreach( $scripts as $handle => $script ) {
        
        wp_enqueue_script( $handle, $script['src'], $script['deps'], ASSEMBLY_THEME_VERSION, $script['footer'] );
        
    }

}

// Enqueue Theme Styles & Scripts
add_action( 'wp_enqueue_scripts', 'asm_bloc_static_enqueue_scripts', 5 );



/*
*  asm_bloc_static_enqueue_scripts
*
*  asm_bloc_static_enqueue_scripts
*
*  @type    action (init)
*  @date    08/12/15
*  @since   0.5.0
*
*  @param   N/A
*  @return  N/A
*/

function asm_bloc_upsell_notice() {
  
  echo '<div class="updated"><p>';
  
    echo wp_kses( sprintf( __( 'Hey! Did you know you can get the PRO version of "Bloc" with <strong>full ticketing support, license keys and plugin updates</strong> (for $49.00) from LOOP Themes? <a href="%1$s" target="_blank">Click here to get it</a>.', 'assembly-bloc' ), 'https://loopthemes.com/checkout/?edd_action=add_to_cart&amp;download_id=4219'), array( 
    'strong' => array(), 
    'a' => array( 
        'href' => array(),
        'target' => array()
    ) 
    ) );

    echo "</p><p>";
  
    echo wp_kses( sprintf( __( 'Alternatively, do you fancy enhancing your theme with some <strong>awesome theme add-ons</strong>? <a href="%1$s">Click here to see the add-ons</a>.', 'assembly-bloc' ), add_query_arg( array(
        'page'      => 'asm-options-addons',
    ), admin_url( 'admin.php' ) ) ), array( 'strong' => array(), 'a' => array( 'href' => array() ) ) );
  
  echo '</p></div>';
  
}

add_action( 'admin_notices', 'asm_bloc_upsell_notice' );